==> gneur-0.0.9a.tar.gz: gneur-0.0.9/src/trayicon.c <==
 /* Sven multimedia keyboard deamon
 * trayicon.c 
 *
 * Copyright (C) 2005 Eugene Morenko(More)
 * mailto: more@irpin.com
 * web: http://sven.linux.kiev.ua/
 * icq:325697438
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include <X11/X.h>
#include <X11/Xlib.h>
#include <gtk/gtk.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <gtk/gtkplug.h>
#include <gdk/gdkx.h>

#include "pixmap.h"
#include "eggtrayicon.h"
#include "trayicon.h"
#include "utils.h"
//#include "prefswin.h"


/*#include "plugin.h"*/

static gboolean tray_icon_release (GtkWidget *widget, GdkEventButton *event,xconf *xnc)
{	
	if (event->button ==3)
	{
		gtk_menu_popdown (GTK_MENU (xnc->tray->popup_menu));
		return FALSE;
	}

	return TRUE;
}

gboolean tray_icon_press (GtkWidget *widget, GdkEventButton *event,xconf *xnc)
{

	if (event->button == 1) 
	{
		return 1;
	}  
	if (event->button == 2) 
	{
		return 1;
	}  	

	gtk_menu_popup (GTK_MENU (xnc->tray->popup_menu), NULL, NULL, NULL,
				NULL, event->button, event->time);

	return 0;
}


GtkWidget* create_menu_icon (xconf *xnc)
{
	GtkWidget *menu;
	GtkWidget *menuitem;
	
	menu = gtk_menu_new ();
	
	
	
	/*menuitem = gtk_image_menu_item_new_from_stock ("gtk-preferences", NULL);
	gtk_widget_show (menuitem);
	gtk_container_add (GTK_CONTAINER (menu), menuitem);
	g_signal_connect(G_OBJECT(menuitem), "activate", G_CALLBACK(xneur_preference),xnc);
	
	menuitem = gtk_separator_menu_item_new ();
	gtk_widget_show (menuitem);
	gtk_container_add (GTK_CONTAINER (menu), menuitem);
	gtk_widget_set_sensitive (menuitem, FALSE);
	
	menuitem = gtk_image_menu_item_new_from_stock ("gtk-about", NULL);
	gtk_widget_show (menuitem);
	gtk_container_add (GTK_CONTAINER (menu), menuitem);
	g_signal_connect ((gpointer) menuitem, "activate",G_CALLBACK (xneur_about),xnc);
	*/

	menuitem = gtk_image_menu_item_new_from_stock ("gtk-quit", NULL);
	gtk_widget_show (menuitem);
	gtk_container_add (GTK_CONTAINER (menu), menuitem);
	g_signal_connect ((gpointer) menuitem, "activate",G_CALLBACK (xneur_exit),xnc);

 	return menu;
}


static gboolean tray_destroyed (GtkWidget *widget, GdkEvent *event, gpointer user_data)
{
	init_tray_icon(user_data);
	printf("Destroy tray icon\n");
	return TRUE;
}

void init_tray_icon(gpointer data)
{
	xconf *xnc = (xconf *)data;
	//STray *stray;
	GtkWidget *evbox;
	
	xnc->tray = g_new0 (STray, 1);
	
	xnc->tray->tooltip = gtk_tooltips_new ();
	
	xnc->tray->popup_menu=create_menu_icon(xnc);
	
	/* Event box */
	evbox = gtk_event_box_new ();
	gtk_event_box_set_visible_window(GTK_EVENT_BOX(evbox),0);
	gtk_widget_set_size_request (evbox, 25, 20);
		
	
	xnc->tray->eggtray = egg_tray_icon_new (_("X Neural Switcher daemon"));
	
	
	gtk_tooltips_set_tip (xnc->tray->tooltip,GTK_WIDGET (xnc->tray->eggtray),_("X Neural Switcher daemon active"),NULL);
			
	g_signal_connect (G_OBJECT (xnc->tray->eggtray), "button_press_event",G_CALLBACK (tray_icon_press),xnc);
	g_signal_connect (G_OBJECT (xnc->tray->eggtray), "button_release_event",G_CALLBACK (tray_icon_release),xnc);
	g_signal_connect(G_OBJECT(xnc->tray->eggtray), "destroy",G_CALLBACK (tray_destroyed), (gpointer) xnc);
		
	xnc->tray->image = create_pixmap_type(17,24,24);
	gtk_container_add(GTK_CONTAINER(evbox),xnc->tray->image);
	gtk_container_add (GTK_CONTAINER (xnc->tray->eggtray), evbox);
	gtk_widget_show_all (GTK_WIDGET (xnc->tray->eggtray));

}

==> gneur-0.1.0.tar.gz: gneur-0.1.0/src/trayicon.c <==
 /* Sven multimedia keyboard deamon
 * trayicon.c 
 *
 * Copyright (C) 2005 Eugene Morenko(More)
 * mailto: more@irpin.com
 * web: http://sven.linux.kiev.ua/
 * icq:325697438
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#include <X11/X.h>
#include <X11/Xlib.h>
#include <gtk/gtk.h>
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>
#include <gtk/gtkplug.h>
#include <gdk/gdkx.h>

#include "pixmap.h"
#include "eggtrayicon.h"
#include "trayicon.h"
#include "utils.h"


static gboolean tray_icon_release (GtkWidget *widget, GdkEventButton *event,xconf *xnc)
{	
	if (event->button ==3)
	{
		gtk_menu_popdown (GTK_MENU (xnc->tray->popup_menu));
		return FALSE;
	}

	return TRUE;
}

gboolean tray_icon_press (GtkWidget *widget, GdkEventButton *event,xconf *xnc)
{

	if (event->button == 1) 
	{
		return 1;
	}  
	if (event->button == 2) 
	{
		return 1;
	}  	

	gtk_menu_popup (GTK_MENU (xnc->tray->popup_menu), NULL, NULL, NULL,
				NULL, event->button, event->time);

	return 0;
}


GtkWidget* create_menu_icon (xconf *xnc)
{
	GtkWidget *menu;
	GtkWidget *menuitem;
	
	menu = gtk_menu_new ();
	
	
	
	menuitem = gtk_image_menu_item_new_from_stock ("gtk-preferences", NULL);
	gtk_widget_show (menuitem);
	gtk_container_add (GTK_CONTAINER (menu), menuitem);
	g_signal_connect(G_OBJECT(menuitem), "activate", G_CALLBACK(xneur_preference),xnc);
	
	menuitem = gtk_separator_menu_item_new ();
	gtk_widget_show (menuitem);
	gtk_container_add (GTK_CONTAINER (menu), menuitem);
	gtk_widget_set_sensitive (menuitem, FALSE);
	
	menuitem = gtk_image_menu_item_new_from_stock ("gtk-about", NULL);
	gtk_widget_show (menuitem);
	gtk_container_add (GTK_CONTAINER (menu), menuitem);
	g_signal_connect ((gpointer) menuitem, "activate",G_CALLBACK (xneur_about),xnc);	

	/*menuitem = gtk_image_menu_item_new_from_stock ("Switch Mode", NULL);
	gtk_widget_show (menuitem);
	gtk_container_add (GTK_CONTAINER (menu), menuitem);
	g_signal_connect ((gpointer) menuitem, "activate",G_CALLBACK (xneur_change_mode),xnc);
	*/
	
	menuitem = gtk_image_menu_item_new_from_stock ("gtk-quit", NULL);
	gtk_widget_show (menuitem);
	gtk_container_add (GTK_CONTAINER (menu), menuitem);
	g_signal_connect ((gpointer) menuitem, "activate",G_CALLBACK (xneur_exit),xnc);

 	return menu;
}


static gboolean tray_destroyed (GtkWidget *widget, GdkEvent *event, gpointer user_data)
{
	init_tray_icon(user_data);
	printf("Destroy tray icon\n");
	return TRUE;
}


void init_tray_icon(gpointer data)
{
	xconf *xnc = (xconf *)data;
	pthread_t xneur_tid;
	GtkWidget *evbox;
	
	xnc->tray = g_new0 (STray, 1);
	
	xnc->tray->tooltip = gtk_tooltips_new ();
	
	xnc->tray->popup_menu=create_menu_icon(xnc);
	
	/* Event box */
	evbox = gtk_event_box_new ();
	gtk_event_box_set_visible_window(GTK_EVENT_BOX(evbox),0);
	gtk_widget_set_size_request (evbox, 25, 20);
		
	
	xnc->tray->eggtray = egg_tray_icon_new (_("X Neural Switcher daemon"));
	
	
	gtk_tooltips_set_tip (xnc->tray->tooltip,GTK_WIDGET (xnc->tray->eggtray),_("X Neural Switcher daemon active"),NULL);
			
	g_signal_connect (G_OBJECT (xnc->tray->eggtray), "button_press_event",G_CALLBACK (tray_icon_press),xnc);
	g_signal_connect (G_OBJECT (xnc->tray->eggtray), "button_release_event",G_CALLBACK (tray_icon_release),xnc);
	g_signal_connect(G_OBJECT(xnc->tray->eggtray), "destroy",G_CALLBACK (tray_destroyed), (gpointer) xnc);
		
	xnc->tray->image = create_pixmap_type(17,24,24);
	gtk_container_add(GTK_CONTAINER(evbox),xnc->tray->image);
	gtk_container_add (GTK_CONTAINER (xnc->tray->eggtray), evbox);
	gtk_widget_show_all (GTK_WIDGET (xnc->tray->eggtray));
}
